@@ -21,7 +21,7 @@ use constant _F_PEAK      =>  8;    # peak elements arrayref, initially undef
 use constant _F_ETA       =>  9;    # "eta" value, initially undef
 use constant _NFIELDS     => 10;
 
-our $VERSION = '0.009';
+our $VERSION = '0.011';
 
 our $_LOG_MAX_ORDER  = 22.1807;         # limit for integer exponentiation
 our $_MAX_ENUM_COUNT = 32768;           # limit for stored rotator set size
@@ -184,7 +184,8 @@ sub set_database {
 sub available {
     my ($class, $base, $exponent) = @_;
     my $order = defined($exponent)? _pow($base, $exponent): $base;
-    my $pds   = $order && $class->_data->get($order, 'base');
+    return undef if !$order || $order > $class->_data->max_order;
+    my $pds   = $class->_data->get($order, 'base');
     return !!$pds && (!defined($exponent) || $base == $pds->base);
 }
 
@@ -543,7 +544,7 @@ Math::DifferenceSet::Planar - object class for planar difference sets
 
 =head1 VERSION
 
-This documentation refers to version 0.009 of Math::DifferenceSet::Planar.
+This documentation refers to version 0.011 of Math::DifferenceSet::Planar.
 
 =head1 SYNOPSIS
 
@@ -569,7 +570,7 @@ This documentation refers to version 0.009 of Math::DifferenceSet::Planar.
 
   ($e1, $e2) = $ds->find_delta($delta);
   ($e1, $e2) = $ds->peak_elements;
-  ($e1)      = $ds->find_delta(($ds->modulus - 1) / 2);
+  ($e1, $e2) = $ds->find_delta(($ds->modulus - 1) / 2);
   $eta       = $ds->eta;
   $bool      = $ds->contains($e1);
 
@@ -633,9 +634,9 @@ of E<8484>_n as points make up a finite projective plane (hence the name).
 
 If t is an element of E<8484>_n coprime to n, S<D E<183> t> =
 S<{d_1 E<183> t, d_2 E<183> t, ..., d_k E<183> t}> is also a difference
-set.  If S<D E<183> t> is a translate of D, t is called a multiplicator
+set.  If S<D E<183> t> is a translate of D, t is called a multiplier
 of D.  If t is coprime to n but either identical to 1 (mod n) or not a
-multiplicator, it is called a rotator.  Rotators of planar difference
+multiplier, it is called a rotator.  Rotators of planar difference
 sets are also rotators of planes as translates of a difference set
 are mapped to translates of the rotated set.  We call a minimal set of
 rotators spanning all plane rotations a rotator base.
@@ -771,25 +772,25 @@ correct and undef if it is not even a set of non-negative integers of
 appropriate size.
 
 An optional third argument I<$factor> controls the check whether the given
-factor is a multiplicator.  For planar difference sets this module
-generates, I<order_base> is indeed a multiplicator.  Thus this combined
+factor is a multiplier.  For planar difference sets this module
+generates, I<order_base> is indeed a multiplier.  Thus this combined
 check should give a good heuristic whether a given set is actually
 representing a planar difference set related to a finite field like the
 ones generated by this module.
 
 If the factor is not specified, the check will be performed with a
-suitable multiplicator, i.e. the smallest base the order is a power of.
-To skip the multiplicator check, a factor of 1 can be specified.
+suitable multiplier, i.e. the smallest base the order is a power of.
+To skip the multiplier check, a factor of 1 can be specified.
 This should be done to avoid using conjectural evidence.
 
 Currently, the return value is an empty string if the small difference
-uniqueness check failed and '0' if it succeeded but the multiplicator
+uniqueness check failed and '0' if it succeeded but the multiplier
 check failed.  This may be taken as a debugging aid, but productive code
 should not rely on particular false values, as future releases may have
 different checks and thus no longer support the same kind of distinction.
 
 If the conjecture that all planar difference sets have order_base as
-multiplicator holds, the combined check will rather efficiently detect
+multiplier holds, the combined check will rather efficiently detect
 most sets that aren't.  For a counterexample to the conjecture, the check
 might return 2 with a high depth value and 0 with a low depth value.
 
@@ -991,10 +992,12 @@ C<($e1, $e2) = $ds-E<gt>find_delta( ($ds-E<gt>modulus - 1) / 2 )>
 =item I<eta>
 
 The prime power conjecture of planar difference sets states that any
-such set has prime power order.  Another conjecture asserts that the
-prime number is a multiplier of the set.  Thus multiplying the set by
-the prime is equivalent to a translation.  The translation amount is
-called I<eta> here and the method I<eta> returns its value.
+such set has prime power order.  This is would also be implied by the
+stronger conjecture that all finite projective planes have prime power
+order.  Another conjecture asserts that the prime number is a multiplier
+of the set.  Thus multiplying the set by the prime is equivalent to
+a translation.  The translation amount is called I<eta> here and the
+method I<eta> returns its value.
 
 Technically, C<$ds-E<gt>eta> is equivalent to
 C<$ds-E<gt>multiply($ds-E<gt>order_base)-E<gt>element(0) >
